#
# spec file for package python-holoviews
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

Name:           python-holoviews%{psuffix}
Version:        1.20.0
Release:        2.5
Summary:        Composable, declarative visualizations for Python
License:        BSD-3-Clause
URL:            https://github.com/holoviz/holoviews
Source0:        https://files.pythonhosted.org/packages/source/h/holoviews/holoviews-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE holoviews-opensuse-pyproject.patch -- for obs builds, code@bnavigator.de
Patch0:         holoviews-opensuse-pyproject.patch
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-bokeh >= 3.1
Requires:       python-colorcet
Requires:       python-numpy >= 1.21
Requires:       python-packaging
Requires:       python-pandas >= 1.3
Requires:       python-panel >= 1.0
Requires:       python-pyviz-comms >= 2.1
Requires:       (python-param >= 1.12 with python-param < 3)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-ipython >= 5.4.0
Recommends:     python-matplotlib >= 3
Recommends:     python-notebook
Suggests:       python-networkx
Suggests:       python-Pillow
Suggests:       python-xarray >= 0.10.4
Suggests:       python-plotly >= 4.0
Suggests:       python-dash >= 1.16
Suggests:       python-streamz >= 0.5.0
Suggests:       python-datashader >= 0.11.1
Suggests:       python-ffmpeg-python
Suggests:       python-netCDF4
Suggests:       python-dask
Suggests:       python-scipy
Suggests:       python-shapely
Suggests:       python-scikit-image
Suggests:       python-pyarrow < 1.0
Suggests:       python-ibis-framework >= 1.3
BuildArch:      noarch
%if %{with test}
##
BuildRequires:  %{python_module holoviews = %{version}}
##
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module contourpy}
BuildRequires:  %{python_module dash >= 1.16}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module datashader >= 0.11.1}
BuildRequires:  %{python_module deepdiff}
BuildRequires:  %{python_module ffmpeg-python}
BuildRequires:  %{python_module ipython >= 5.4.0}
BuildRequires:  %{python_module keyring}
BuildRequires:  %{python_module matplotlib >= 3}
BuildRequires:  %{python_module nbconvert}
BuildRequires:  %{python_module nbsmoke}
BuildRequires:  %{python_module netCDF4}
BuildRequires:  %{python_module networkx}
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module plotly >= 4.0}
BuildRequires:  %{python_module pytest-asyncio >= 0.24}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rfc3986}
BuildRequires:  %{python_module scikit-image if %python-base < 3.13}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module shapely}
BuildRequires:  %{python_module streamz >= 0.5.0}
BuildRequires:  %{python_module xarray >= 0.10.4}
%endif
%python_subpackages

%description
HoloViews is a Python library for automated plotting of annotated
data.

Instead of building a plot using direct calls to a plotting library,
the developer instead first describes the data with semantic
information and then additional metadata to determine more detailed
aspects of the visualization. This approach provides automatic
visualization that can be requested at any time as the data evolves,
rendered automatically by one of the supported plotting libraries
(such as Bokeh or Matplotlib).

%prep
%autosetup -p1 -n holoviews-%{version}

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/holoviews
%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/holoviews/util/command.py
sed -i "s|^#!.*%{_bindir}/env python$|#!%__$python|" %{buildroot}%{$python_sitelib}/holoviews/util/command.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/holoviews/util/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/holoviews/util/
%fdupes %{buildroot}%{$python_sitelib}
}
%endif

%if %{with test}
%check
# Flaky
donttest="test_cell_opts_plot_float_division or test_cell_opts_style"
# tool not available in obs setup (?)
donttest+=" or test_span_not_cloned_crosshair"
# These fail on 32-bit -- gh#holoviz/holoviews#4778
if [[ $(getconf LONG_BIT) -eq 32 ]]; then
    donttest+=" or (DatashaderAggregateTests and test_rasterize_regrid_and_spikes_overlay)"
    donttest+=" or (DatashaderAggregateTests and test_rgb_regrid_packed)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_image_string_aggregator)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_image)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_quadmesh_string_aggregator)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_quadmesh)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_trimesh_ds_aggregator)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_trimesh_node_explicit_vdim)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_trimesh_node_vdim_precedence)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_trimesh_string_aggregator)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_trimesh_vertex_vdims)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_trimesh_zero_range)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_trimesh)"
    donttest+=" or (DatashaderRegridTests and test_regrid_max)"
    donttest+=" or (DatashaderRegridTests and test_regrid_mean_xarray_transposed)"
    donttest+=" or (DatashaderRegridTests and test_regrid_mean)"
    donttest+=" or (DatashaderRegridTests and test_regrid_rgb_mean)"
    donttest+=" or (DatashaderRegridTests and test_regrid_upsampling)"
    donttest+=" or (DatashaderTestCase and test_datashade_curve)"
    donttest+=" or (TestDecollation and test_decollate_datashade_kdims_layout)"
    donttest+=" or (TestDecollation and test_decollate_datashade_kdims)"
    donttest+=" or (TestDecollation and test_decollate_spread)"
    donttest+=" or (TestDimTransforms and test_digitize)"
    donttest+=" or (TestLinkSelectionsBokeh and test_datashade_in_overlay_selection)"
    donttest+=" or (TestLinkSelectionsBokeh and test_datashade_selection)"
    donttest+=" or (TestLinkSelectionsPlotly and test_datashade_in_overlay_selection)"
    donttest+=" or (TestLinkSelectionsPlotly and test_datashade_selection)"
    donttest+=" or (TestPointerCallbacks and test_tap_datetime_out_of_bounds)"
    donttest+=" or (TestPointerCallbacks and test_pointer_x_datetime_out_of_bounds)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_dask_trimesh)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_dask_trimesh_implicit_nodes)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_dask_trimesh_with_node_vdims)"
    donttest+=" or (DatashaderRasterizeTests and test_rasterize_pandas_trimesh_implicit_nodes)"
    donttest+=" or (DimensionDefaultTest and test_validate_default_against_values)"
fi

%pytest -n auto holoviews -k "not ($donttest)"
%endif

%post
%python_install_alternative holoviews

%postun
%python_uninstall_alternative holoviews

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc README.md
%python_alternative %{_bindir}/holoviews
%{python_sitelib}/holoviews-%{version}.dist-info
%{python_sitelib}/holoviews/
%endif

%changelog
* Thu Dec  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python313 tests with scikit-image (not available yet)
* Thu Nov 28 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.20.0
  [#]# Enhancements
  * De-parameterize the options Keywords objects (#6314)
  * Freeze models while updating plot(s) (#6315)
  * Support hit-tested group-wise wheel zoom renderers for
    subcoordinate_y (#6277)
  * Adds Bokeh 3.5 enhancements to RangeToolLink (#6341)
  * Add MultiAxisTap stream (#6374)
  * Add sublabel_index and sublabel_skip option for matplotlib
    backend (#6375)
  * Handle datetimes and empty selections better for inspect
    operations (#6377)
  * Improve following behavior when streaming (#6318)
  * Enh: Add Scalebar support for subcoordinate_y plots (#6403,
    [#6420])
  * Support async callbacks for popup (#6390)
  * Add popup position and anchor (#6414)
  [#]# Bug fixes
  * Wrap popup in set_curdoc (#6337)
  * Fixes popup being invisible forever after closing once (#6347)
  * Disable simple id in notebook (#6367)
  * Ensure pixel_ratio is applied when computing resampling
    coordinates (#6373)
  * Add support for rendering HLine, VLine and Span on multi_y
    (#6376)
  * Drop the z dimension from ImageStack DataArray before shading
    (#6378)
  * Improve datetime support for continuous hv.Bars (#6365)
  * Don't clone Span in HoverTool (#6387)
  * Ensure proper cleanup of stream subscribers (#6389)
  * Handle datetime selection in the cuDF interface (#6407)
  * Fix popup positioning on polygons (#6411)
  * Fix a problem where linked selections were resulting in
    repeated columns (#6336)
  * Ensure streams are correctly mapped to plots (#6415)
  * Fix Bars width for small discrete differences on the x-axis
    (#6428)
  * Documentation fixes (#6392, #6421)
  * Fix rasterizing a Path where categorical values include empty
    strings (#6429)
  [#]# Compatibility
  * Handle DeprecationWarning from Pandas (#6346, #6391)
  * Compatibility with Ibis 9.5 (#6371), Python 3.13 (#6383), cuDF
    24.10 (#6409), and Matplotlib 3.10 (#6431)
- Replace ignore-pandas-warning.patch with
  holoviews-opensuse-pyproject.patch
* Sun Sep 22 2024 Ben Greiner <code@bnavigator.de>
- Make testing multibuild in order to avoid resolver errors with
  numba and numpy
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Unpin numpy 2
* Mon Jul  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.19.1:
  * New features
    + Add support for popups on selection streams
    + Add scalebar support
  * Enhancements
    + Add color to bars for Plotly backend
    + Override Curve's count aggregator default to self_intersect=False
    + Zoom tools automatically vertically scaled on subcoordinate_y overlays
    + Use tsdownsample library for downsampling if available
    + Add viewport downsample algorithm
    + Optimize downsample1d when data is shared between layers
    + Support dictionary cmaps for ImageStack
    + Expose hit_dilation in PointPlot
    + Improve autocompletion for lazy module
    + Subcoordinate_y: reverse the renderers by default
    + Add hover_tooltips, hover_mode, hover_formatters opts to easily modify
    hover
    + Expose setting hard navigable bounds
    + Add a zoom tool per subcoordinate_y group
    + Support all Bokeh Text style opts in hv.Labels and hv.Text
    + Implement support for retaining Pandas index
    + Add operation for group-wise normalisation
    + Allow Bars to be plotted on continuous axes
    + Add min_interval and max_interval to the RangeToolLink
    + Add support for rasterizing geopandas dataframes directly
    + Allow options for non-enabled backends
    + Support ImageStack in dynspread
    + Add support for cticks
    + Support title font size in Plotly backend
    + Hold rendering until a plot has been fully updated
    + Make Dimension.label source of truth for Dimension identity
    + Allow subcoordinates to be drawn from NdOverlay dimensions
    + Add stream transform
  * Bug fixes
    + Ensure no auto index is created when a kdim is part of a multi index
    + Fix hv.Bars with only one value in it
    + Set zIndex of Popup to 1000
    + Handle boolean input in categorically grouped Bars plots
    + Also check for pd.NA in is_nan
    + Don't show figures toolbar on GridSpace
    + Update merge_tool
    + Don't raise KeyError if options don't contain None
    + Force vdims to strings for ImageStack
    + Fixes to Bokeh BoxWhisker
    + Improve groupby behavior for operation histogram
    + Ensure plot ranges for all renderers are combined in auto-ranging
    + Ensure that the downsample algorithm m4 n_out is always a multiple of 4
    + Subcoordinate_y: respect ylim
    + Bug fix for player example pause button
    + Clone if a Tool is as Bokeh model
    + Fix violin plot in Plotly
    + Don't error on TypeError in DaskInterface when sorting
    + Fix hv.help if Info.store is None
    + Change how upper limit is taken for color_levels
    + Fix vectorfield hover
    + Ensure Range streams and RangeToolLink respect subcoordinate axis range
    + Fix pickling state
    + Fix colab rendering
    + Disable batching when subcoordinate_y is enabled
    + Ensure downsample works with non-contiguous arrays
    + Fix issue with range lookups in (y)-axis creation
  * Compatibility
    + Compatibility with Bokeh 3.5
    + Compatibility with Matplotlib 3.9
    + pandas: Fix observed FutureWarning for categorial groupby
    + Lazy load dask.dataframe in operations.datashader
    + Numpy 2.0 compatibility
    + Update to support cudf 2024.06
- Remove rpmlintrc, no longer needed.
- Add patch ignore-pandas-warning.patch:
  * Ignore warning from Pandas.
- Limit numpy to < 2.
* Sat Mar  2 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no xarray anymore
* Sun Feb 18 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.18.3
  * Fix BoundsX and BoundsY regression (#6099)
  * Fix rasterize regression (#6102)
  * Fix link selection for empty Layout (#6110)
  * Don't pin notebook in conda recipe for pyviz channel (#6108)
* Tue Feb  6 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.18.2:
  This minor release includes a number of bug fixes and documentation
  updates, as well as compatibility updates for xarray 2023.12 and
  Pandas 2.2.
  * Enhancements:
  - Update contour line calculations to use ContourPy's LineType.ChunkCombinedNan (#5985)
  - Use sys.executable for check_output (#5983)
  - Updates to show_versions ((#6072), (#6081))
  * Bug fixes:
  - Support color_key in datashade when intermediate step is an ImageStack (#5994)
  - Fix hist on overlay (#5995)
  - Set proper context before triggering streams (#6000)
  - Support partial bound function (#6009)
  - Add norm in init_artists in holoviews/plotting/mpl/raster.py (#6029)
  - Fix linking elements that are transformed by a Compositor (#6003)
  - Add datetime hover information for selector (#6023, (#6039))
  - Only evaluate rx if it is an Reactive Expression ((#6014))
  - Ensure partial methods can be used as dmap callables ((#6063))
  - Del frame after stack level is found in deprecated ((#6085))
  * Compatibility:
  - Compatibility updates with xarray 2023.12 (#6026)
  - Add extra check to detect if we are in jupyterlite (#6007)
  - Compatibility updates with Pandas 2.2 ((#6074), (#6078))
  - Add Comm on_open handler to initialize the server comm ((#6076))
  * Documentation:
  - Fix docs (#5996)
  - Fix Param usage in the Plot and Renderers guide (#6001)
  - Fixing URLs to bokeh project (#6005)
  - Fix to broken urls in example gallery pages ((#6038))
  - Replace Google Analytics with GoatCounter ((#6048))
  - Add downloads badges ((#6088))
  * Maintenance:
  - Change to pytest-rerunfailures (#5984)
  - Holoviews maintenance (#5987)
  - Add log_cli_level = "INFO" to pytest (#5989)
  - Add shell pre-commit hook (#5991)
  - Enable Bugbear 904 (#5992)
  - Part 1, modernize test suite (#5954)
  - Enforce labels (#5996)
  - Add lower pin to scipy (#6032)
  - Skip Deploying_Bokeh_Apps.ipynb on Windows ((#6070))
  - Fix failing Windows tests ((#6087))
* Thu Jan 11 2024 Daniel Garcia <daniel.garcia@suse.com>
- removed numpy125.patch and python3-only.patch, not needed anymore
- Update to 1.18.1:
  * This release contains a small number of bug fixes and
    compatibility updates
  * Bug fixes:
  - Account for overlaid elements when using subcoordinates_y (#5950)
  - Fix groupby option for vectorized annotations (#5956)
  - Fix and improvements to ImageStack (#5961)
  - Do not allow partial matches when updating OverlayPlot (#5962)
  - Always ravel array in unique_array (#5969)
  * Compatibility:
  - Update Stamen maps with new URL (#5967)
  - Compatibility updates for Numpy 2.0 (#5979)
  * Maintenance:
  - General maintenance (#5955)
- 1.18.0:
  This release includes new features, improvements, and bug fixes. Among
  these are the new elements. First is the ImageStack element allows you
  to easily visualize a 3D array, while the VLines, HLines, VSpans, and
  HSpans elements allow you to visualize vertical and horizontal lines
  and spans easily. In addition, this release includes support for
  subcoordinate systems in the y-axis and various other enhancements and
  bug fixes. This release adds support for the newest Python 3.12 and
  Bokeh 3.3 and drops support for Python 3.8 and Bokeh 2.
* Thu Aug 31 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.17.1
  * interactive twin-axis support
  * ability to set custom options on plot components with backend_opts
  * datashaders where and summary aggregators are now supported
  * rasterize now has a selector option
  * Bokeh figures with the same labels will synchronize muteness or
    visibility across different figures
  * several enhancements and bug fixes
- Add upstream numpy125.patch
- Add python3-only.patch (sent upstream)
* Wed Jun  7 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.16.1
  * This release contains a small number of important bug fixes and
    enhancements. Many thanks to @philippjfr and @Hoxbro.
  * This release includes a breaking change as notebooks will no
    longer be inlining as default. This change will reduce the size
    of the notebook files and, more importantly, address an
    upstream issue in Jupyter where running hv.extension would give
    an error when used in a notebook.
  [#]# Critical bug fixes and compatibility:
  * Add enable_mathjax and set it and inline to False (#5729)
  * Update to support Datashader on Python 3.11 (#5720)
  [#]# Enhancements:
  * Add show_versions helper function (#5725)
  * Ignore known model warning in VS Code (#5734)
  * Add workaround for plots where the objects in a figure would
    overlap (#5733)
- Version 1.16.0
  * This release includes many new features, improvements, and bug
    fixes. Among the highlights are support for Bokeh 3.1 and Panel
    1.0, both of which come with a wide range of new features and
    enhancements. Time series support has also been improved, with
    auto-ranging along one axis, a new downsample algorithm, and
    having WebGL enabled by default. In addition, the release
    includes various other enhancements and bug fixes.
  * We would like to thank the many users who contributed to this
    release by filing bug reports, providing new features, and bug
    fixes. We want to give a special shout-out to existing
    contributors @ianthomas23, @jlstevens, @jordansamuels,
    @maximlt, @philippjfr, @TheoMathurin, @Yura52, and @Hoxbro, as
    well as new contributors @GeoVizNow, @JRRudy1, @keewis,
    @michaelaye, and @wendrul.
  * This minor version will be the last to support Python 3.7. The
    next minor version will require Python 3.8 or higher. In the
    next release, holoviews.annotate will start giving a
    deprecation warning about its future move to the new package
    HoloNote.
  [#]# New features:
  * Support for Bokeh 3.1 and Panel 1.0 (#5388, #5620, #5640,
    [#5679], #5683, #5692, #5703)
  * Implement auto-ranging support along one axis (#5554, #5609)
  * Add Largest Triangle Three Buckets (LTTB) as a downsample
    algorithm (#5552)
  * Enable WebGL by default (#5708)
  [#]# Enhancements:
  * Improve legend_cols support for Bokeh 3 (#5669)
  * Add convenience getter interface to opts (#5606)
  * Ensure .stack works on areas with different vdims (#5693)
  * Add muted support to PointPlot like hv.Scatter (#5705)
  * Automatic detect comms without calling pn.extension() (#5645)
  * Add support for extra Hovertool variables in a Bokeh's quadmesh
    with 2D coordinates (with tests) (#5638)
  * Change hv.Rectangles to internally use Bokeh Quad and not Rect
    to support logarithmic axis in WebGL (#5664, #5702)
  [#]# Bug fixes:
  * Ensure spatial_select in non-zero indexed DataFrame is applied
    right (#5625)
  * Fix error handling for plotting class lookups on empty
    DynamicMap/HoloMap (#5604)
  * Fix active_tools to only be set for enabled tools (#5616)
  * Fix legend display when using categorical datashade on GPU
    (#5631)
  * Adding GeoDataFrame to DataConversion (#5325)
  * Don't emit warnings when the toolbar is disabled (#5691)
  * Don't try to find the closest match if the input is empty
    (#5700)
  * Only use long_name if it is a string (#5646)
  * Use Matplotlib's public API to list the colormaps (#5598)
  [#]# Compatibility:
  * Add Param 2.0 support (#5667, #5641, #5680, #5704)
  * Add Pandas 2.0 support (#5662)
  * Update types.functiontype to collections.abc.callable (#5636)
  * Improve error message for categorical data when used with
    datashade (#5643)
  * Don't disable Jedi completion by default (#5701)
  [#]# Known issues:
  * BoxEditTool is not yet supported with the new internals of
    hv.Rectangle.
  [#]# Removals:
  * Raise DataError for non-string column names in DataFrame
    (#5654)
  * Remove deprecated tile sources (#5654)
  * Removed support for apply_groups for old option groups
    signature (#5497)
- Drop holoviews-pr5649-ipykernel.patch
* Sun Mar 26 2023 Ben Greiner <code@bnavigator.de>
- Don't test xarray on python38: dropped support
- Don't test dash on python311: no support yet
- Don't test datashader on python38, python311: both of the above
- Add holoviews-pr5649-ipykernel.patch gh#holoviz/holoviews#5649
- Add disk constraint: big installation
* Wed Feb  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.15.4
  * Make lasso select mask values using a Dask-compatible method
    (#5568)
  * Make plotly legend group unique (#5570)
  * Set pan and wheel_zoom as the default Bokeh active tools
    (#5480)
  * Enable rendering colorbars on bokeh GraphPlots (#5585)
  * Add Plotly Scatter3d documentation and fix colorbar title
    (#5418)
  * Only trigger range-update once in callbacks (#5558)
  * Ensure dynamically created subplots can be updated (#5555)
  * Fix start of stack-level in deprecations (#5569)
  * When sorting colormap records, replace None with an empty
    string (#5539)
  * Fix annotator in Geoviews by adding deserialization of
    non-deserialized base64 data (#5587)
  * Fix hv.Empty not working in AdjointLayout plot (#5584)
  * Check for categorical data to histogram (#5540)
  * Fix clim_percentile (#5495)
  * Compatibility with Shapely 2.0 (#5561)
  * Compatibility with Numpy 1.24 (#5581)
  * Compatibility with Ibis 4.0 (#5588)
- Release to 1.15.3
  * Fix for empty opts warning and incorrect clearing semantics
    (#5496)
  * Fix potential race condition in the Options system (#5535)
  * Add support to Python 3.11 (#5513)
  * Cleanup the top __init__ module (#5516)
- PEP517 build
* Tue Nov 22 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.15.2
  [#]# Bug fixes:
  * Fix support for jupyterlite (#5502)
  * Improve error message for hv.opts without a plotting backend
    (#5494)
  * Fix warnings exposed in CI logs (#5470)
  * Thanks to @maximlt for various CI fixes (#5484, #5498, #5485)
  [#]# Enhancement:
  * Allow Dimension objects to accept a dictionary specification
    (#5333)
  * Refactor to remove iterrows for loop from connect_edges_pd
    (#5473)
  [#]# Deprecations:
  * Promoted DeprecationWarning to FutureWarning when using pandas
    DataFrames with non-string column names. This will not change
    any functionality but will start warning users about
    functionality that will be deprecated in future.
  * Upgrade warning for invalid dataframe column names (#5472)
- Release 1.15.1
  [#] Enhancements:
  * Sort output of decimate operation so that it can be used with
    connected Elements (Curve, Area, etc.) (#5452)
  * Ensure HoloViews is importable from a pyodide webworker (#5410)
  * Add support for stepwise Area plots (#5390)
  * Better error message for hv.Cycle when incompatible backend
    activated (#5379)
  * Improvements to VSCode notebook support (#5398)
  * Protect matplotlib tests from global styles (#5311)
  * Faster hashing for arrays and pandas objects (#5455)
  * Add pre-commit hooks to CI actions and fixes to pytest
    configuration (#5385, #5440)
  [#]# Bug Fixes:
  * Allow import of numpy 1.12 (#5367)
  * Fixes handling of iterables in Overlays (#5320)
  * Always return a string when using hv.Dimension.pprint_value
    (#5383)
  * Support widgets in slices for loc and iloc (#5352)
  * Take account of labeled dimension in Bokeh plotting classes
    (#5404)
  * Fix handling of pandas Period ranges (#5393)
  * Fixed declaration of Scatter to Selection1DExpr (#5413)
  * Ensure rangesupdate event fires on all plots with linked axes
    (#5465)
  * Fixed fallback to shapely spatial select (#5468)
  * Many thanks to @Hoxbro for many miscellaneous plotting fixes,
    including fixes to plotting of BoxWhisker, VectorField elements
    (#5397, #5450, #5400, #5409, #5460))
  [#]# API:
  * In future, HoloViews will not allow non-string values for
    pandas DataFrame column names. This deprecation cycle starts by
    issuing a DeprecationWarning that should not be visible to
    users.
  + Issue DeprecationWarning for invalid DataFrame column types
    (#5457)
- Release 1.15.0
  * This is a major release with a large number of new features and
    bug fixes, as well as updates to Python and Panel
    compatibility.
  [#]# Compatibility:
  * Python 2 support has finally been dropped with 1.14.9 as the
    last release supporting Python 2
  * HoloViews now requires panel >0.13.1 (#4329)
  * Colormaps for the output of the datashade operation have
    changed to address holoviz/datashader#357; see
    rescale_discrete_levels below. To revert to the old colorbar
    behavior, set ColorbarPlot.rescale_discrete_levels = False in
    the bokeh or mpl plotting modules as appropriate.
  * Updated Sankey algorithm means that some users may need to
    update the node_padding parameter for plots generated with
    earlier releases.
  [#]# Major features:
  * After a long period of hotfix releases for the 1.14.9 series,
    many new features on the master branch have been released.
    Features relating to datashader support, linked selection and
    improvements to the Bokeh plotting backend are called out in
    their own sections.
  * Support constructor interface from a spatialpandas
    GeometryArray (#5281)
  * Allow plotting anonymous pandas.Series (#5015)
  * Add support for rendering in pyodide/pyscript (#5338, #5321,
    [#5275])
  [#] Datashader features:
  * The following new features have been added to the datashader
    support in HoloViews, mainly focused on Datashader's new
    support for antialiasing lines as well as the new
    rescale_discrete_levels colormapping option.
  * Add automatic categorical legend for datashaded plots (#4806)
  * Implement line_width support when rasterizing spatialpandas
    paths (#5280)
  * Expose rescale_discrete_levels in the Bokeh backend (#5312)
  * Set rescale_discrete_levels=True by default (#5268)
  [#]# New linked selection features:
  * Implement linked_selection.filter method (#4999)
  * Allow passing custom selection_expr to linked selections filter
    (#5012)
  * Fix AdjointLayout in link_selections (#5030)
  [#]# New features for the Bokeh plotting backend:
  * Add legend_labels option to allow overriding legend labels
    (#5342)
  * Updated sankey algorithm to d3-sankey-v0.12.3 (#4707)
  [#] Other enhancements:
  * Optimize and clean up options system (#4954)
  * Optimize lasso selection by applying box-select first (#5061)
    [#5061]
  * Support ibis-framework version 3 (#5292)
  * Add OpenTopoMap as a tile source (#5052)
  * Show all histograms of an Overlay (#5031)
  [#]# Bug fixes:
  * Fix batch watching and linking of parameters in Params stream
    (#4960, #4956)
  * Ensure Plot.refresh is dispatched immediately if possible
    (#5348)
  * Fix datashader empty overlay aggregation (#5334)
  * Fixed missing handling of nodata for count aggregator with
    column (#4951)
  * Handle pd.NA as missing data in dtype=object column (#5323)
  * Forward DynamicMap.hist dimension parameter to histogram
    creation (#5037)
  * Remove numpy pin from examples (#5285)
  * Fix vmin/vmax deprecation on matplotlib HeatMapPlot (#5300)
  * Don't skip each renderer's load_nb call when multiple extension
    calls are made in a single cell (#5302)
  * Set plotly range correctly for log axis (#5272)
  * Sanitize uses of contextlib.contextmanager (#5018)
  * Ensure overlay_aggregate is not applied for anti-aliased lines
    (#5266)
  * Switch to using bokeh rangesupdate event for Range streams
    (#5265)
  * Fixes for bokeh Callbacks (#5040)
  * Fix for attribute error in matplotlib CompositePlot (#4969)
  * Silenced inappropriate deprecation warnings and updated
    deprecation settings in options system (#5345, #5346)
* Tue Jun  7 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.14.9
  * This release contains a small number of important bug fixes as
    well as support for the newly added antialiasing option for
    line rendering in datashader.
  * Improvements to extension loading, improving visual appearance
    in JupyterLab when no logo is used and a check to avoid loading
    unnecessary JavaScript. (#5216, #5249)
  * Add support for setting antialiased line_width on datashader
    line aggregation as well as pixel_ratio setting (#5264, #5288)
  * Added options to customize hover line_(width|join|cap|dash)
    properties (#5211)
  * Fix to respect series order in stacked area plot (#5236)
  * Support buffer streams of unspecified length (#5247) (#5247)
  * Fixed log axis lower bound when data minimum is <= 0 (#5246)
  * Declared GitHub project URL in setup.py (#5227)
  * Fixed streaming Psutil example application (#5243)
  * Respecting Renderer's center property for HoloViews pane
    (#5197)
  * Fix vmin/vmax deprecation in HeatMap plot for matplotlib > 3.3
    (#5300)
- Release 1.14.8
  * Fixed xarray validation for aliased coordinate (#5169)
  * Fixed xaxis/yaxis options with Matplotlib (#5200)
  * Fixed nested widgets by handling list or tuple values in
    resolve_dependent_value utility (#5184)
  * Fixed issue handling multiple widgets without names (#5185)
  * Fix overlay of two-level categorical plots and HLine (#5203)
  * Added support for Ibis > 2.0 (#5204)
  * Allow lower dimensional views on arbitrary dimensioned elements
    (#5208)
  * Fix escaping of HTML on Div element (#5209)
  * Miscellaneous fixes to unit tests, including cudf test fixes as
    well as addition of Python 3.9 and 3.10 to the test matrix
    (#5166, #5199, #5201, #5206)
* Mon Jan 31 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.14.8a1
  * nominally a prerelease, but essentially 1.14.7 plus
    gh#holoviz/holoviews#516 : Fix for xarray coordinate validation
- Required to fix hvplot
- Datashader also requires dask, so don't test on Python 3.10
  either
* Sat Jan 29 2022 Ben Greiner <code@bnavigator.de>
- Don't test with dask for Python 3.10: not supported yet.
* Wed Jan 19 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.14.7
  * Support xyzservices.TileProvider as hv.Tiles input (#5062)
  * Allow reversed layout/overlay binary operators for + and * to
    be used with custom objects (#5073)
  * Fix internal numpy.round usage (#5095)
  * Remove dependency on recent Panel release by importing bokeh
    version from util module (#5103)
  * Add missing bounds for the cache_size Parameter (#5105)
  * Add current_key property to DynamicMap (#5106)
  * Pin freetype on Windows to avoid matplotlib error (#5109)
  * Handle the empty string as a group name (#5131)
  * Do not merge partially overlapping Stream callbacks (#5133)
  * Fix Violin matplotlib rendering with non-finite values (#5135)
  * Fix matplotlib colorbar labeling for dim expressions (#5137)
  * Fix datetime clipping on RangeXY stream (#5138)
  * Ensure FreehandDraw renders when styles are set (#5139)
  * Validate dimensionality of xarray interface data (#5140)
  * Preserve cols when overlaying on layout (#5141)
  * Fix Bars legend error when overlaid with annotation (#5142)
  * Fix plotly Bar plots containing NaNs (#5143)
  * Do not raise deprecated .opts warning for empty groups (#5144)
  * Handle unsigned integer dtype in datashader aggregate operation
    (#5149)
  * Delay projection comparison to optimize geoviews (#5152)
  * Utility to convert datetime64 to int64 and test suite
    maintenance (#5157)
  * Fix for Contours consistent of empty and nonempty paths (#5162)
  * Fix fig_bounds description in Plotting_with_Matplotlib.ipynb
    (#4983)
  * Fix broken link in Gridded user guide (#5098)
  * Switch to the Pydata Sphinx theme (#5163)
* Sat Sep 18 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.14.6
  * Compatibility for bokeh 2.4 and fixes to processing of falsey
    properties and visible style property (#5059, #5063)
  * Stricter validation of data.interface before calling subclass
    (#5050)
  * Fix to prevent options being ignored in some cases (#5016)
  * Improvements to linked selections including support for linked
    selection lasso for cudf and improved warnings   * (#5044,
    [#5051])
  * Respect apply_ranges at range computation level (#5081)
  * Keep ordering of kdim when stacking Areas (#4971)
  * Apply hover postprocessor on updates (#5039)
- Release 1.14.5
  * Support for pandas>=1.3 (#5013)
  * Various bug fixes relating to dim transforms including the use
    of parameters in slices and the use of getattribute
    (#4993, #5001, #5005)
- Release 1.14.4
  Enhancements:
  * Reenable SaveTool for plots with Tiles (#4922)
  * Enable dask TriMesh rasterization using datashader (#4935)
  * Use dataframe index for TriMesh node indices (#4936)
  Bug fixes:
  * Fix hover for stacked Bars (#4892)
  * Check before dereferencing Bokeh colormappers (#4902)
  * Fix multiple parameterized inputs to dim (#4903)
  * Fix floating point error when generating bokeh Palettes (#4911)
  * Fix bug using dimensions with label on Bars (#4929)
  * Do not reverse colormaps with '_r' suffix a second time (#4931)
  * Fix remapping of Params stream parameter names (#4932)
  * Ensure Area.stack keeps labels (#4937)
  Compatibility:
  * Unfortunately a number of tile sources are no longer publicly
    available. Attempting to use these tile sources will now issue
    warnings unless hv.config.
  * raise_deprecated_tilesource_exception is set to
    True in which case exceptions will be raised instead.
  * The Wikipedia tile source is no longer available as it is no
    longer being served outside the wikimedia domain. As one of
    the most frequently used tile sources, HoloViews now issues a
    warning and switches to the OpenStreetMap (OSM) tile source
    instead.
  * The CartoMidnight and CartoEco tile sources are no longer
    publicly available. Attempting to use these tile sources will
    result in a deprecation warning.
- Refresh remove_nose.patch: with sed line is simpler
* Fri Apr  9 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.14.3
  Enhancements:
  * Allow applying linked selections to chained DynamicMap (#4870)
  * Issuing improved error message when __radd__ called with an
    integer (#4868)
  * Implement MultiInterface.assign (#4880)
  * Handle tuple unit on xarray attribute (#4881)
  * Support selection masks and expressions on gridded data (#4882)
  Bug fixes:
  * Handle empty renderers when merging HoverTool.renderers (#4856)
  Compatibility:
  * Support matplotlib versions >=3.4 (#4878)
- Skip tests not taking into account new functionality with
  matplotlib 3.4.1 -- gh#holoviz/holoviews#4886
* Thu Mar  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.14.2:
  * Enhancements:
  - Bokeh 2.3 compatibility (gh#holoviz/holoviews#4805,
    gh#holoviz/holoviews#4809).
  - Supporting dictionary streams parameter in DynamicMaps and
    operations (gh#holoviz/holoviews#4787,
    gh#holoviz/holoviews#4818, gh#holoviz/holoviews#4822).
  - Support spatialpandas DaskGeoDataFrame
    (gh#holoviz/holoviews#4792).
  - Disable zoom on axis for geographic plots
    (gh#holoviz/holoviews#4812
  - Add support for non-aligned data in Area stack classmethod
    (gh#holoviz/holoviews#4836).
  - Handle arrays and datetime ticks
    (gh#holoviz/holoviews#4831).
  - Support single-value numpy array as input to HLine and VLine
    (gh#holoviz/holoviews#4798).
  * Bug fixes:
  - Ensure link_inputs parameter on operations is passed to
    apply (gh#holoviz/holoviews#4795).
  - Fix for muted option on overlaid Bokeh plots
    (gh#holoviz/holoviews#4830).
  - Check for nested dim dependencies
    (gh#holoviz/holoviews#4785).
  - Fixed np.nanmax call when computing ranges
    (gh#holoviz/holoviews#4847).
  - Fix for Dimension pickling (gh#holoviz/holoviews#4843).
  - Fixes for dask backed elements in plotting
    (gh#holoviz/holoviews#4813).
  - Handle isfinite for NumPy and Pandas masked arrays
    (gh#holoviz/holoviews#4817).
  - Fix plotting Graph on top of Tiles/Annotation
    (gh#holoviz/holoviews#4828).
  - Miscellaneous fixes for the Bokeh plotting extension
    (gh#holoviz/holoviews#4814, gh#holoviz/holoviews#4839).
  - Miscellaneous fixes for index based linked selections
    (gh#holoviz/holoviews#4776).
  * Documentation:
  - Expanded on Tap Stream example in Reference Gallery
    (gh#holoviz/holoviews#4782).
  - Miscellaneous typo and broken link fixes
    (gh#holoviz/holoviews#4783, gh#holoviz/holoviews#4827,
    gh#holoviz/holoviews#4844, gh#holoviz/holoviews#4811).
- Drop holoviews-pr4803-dask2021.patch: upstreamed.
* Thu Feb 11 2021 Ben Greiner <code@bnavigator.de>
- NEP 29: NumPy dropped Python 3.6 -- skip python36 build for TW
* Wed Feb  3 2021 Ben Greiner <code@bnavigator.de>
- Update to v1.14.1
  * Fix issues with linked selections on tables (#4758)
  * Fix Heatmap alpha dimension transform (#4757)
  * Do not drop tools in linked selections (#4756)
  * Fixed access to possibly non-existant key (#4742)
- Add holoviews-pr4803-dask2021.patch to support dask >= 2021.1
  gh#holoviz/holoviews#4803
* Wed Jan 13 2021 Benjamin Greiner <code@bnavigator.de>
- rpm 4.16 requires strings to be inside quotes for conditionals
- remove wrong python2 BuildRequires
* Sun Jan  3 2021 Benjamin Greiner <code@bnavigator.de>
- Update to v1.14.0
  This release brings a number of major features including a
  new IbisInterface, new Plotly Dash support and greatly
  improved Plotly support, and greatly improved interaction
  and integration with Datashader. Many thanks to the many
  contributors to this release, whether directly by submitting
  PRs or by reporting issues and making suggestions.
  Specifically, we would like to thank @philippjfr,
  @jonmmease, and @tonyfast for their work on the
  IbisInterface and @jonmmease for improving Plotly support,
  as well as @kcpevey, @Hoxbro, @marckassay, @mcepl, and
  @ceball for various other enhancements, improvements to
  documentation and testing infrastructure. In addition,
  thanks to the maintainers @jbednar, @jlstevens and
  @philippjfr for contributing to this release. This version
  includes a large number of new features, enhancements, and
  bug fixes.
  It is important to note that version 1.14 will be the last
  HoloViews release supporting Python 2.
  Major features:
  * New Plotly Dash support (#4605)
  * New Plotly support for Tiles element (#4686)
  * New IbisInterface (#4517)
  * Greatly improved Datashader rasterize() (#4567). Previously,
    many of the features of Datashader were available only
    through datashade, which rendered data all the way to RGB
    pixels and thus prevented many client-side Bokeh features
    like hover, colorbars, dynamic colormaps, etc. rasterize now
    supports all these Bokeh features along with nearly all the
    Datashader features previously only available through
    datashade, including (now client-side) histogram
    equalization with cnorm='eq_hist' and easy control of
    transparency via a new Dimension.nodata parameter. See the
    Large Data User Guide for more information.
  Enhancements:
  * Implemented datashader aggregation of Rectangles (#4701)
  * New support for robust color limits (clim_percentile) (#4712)
  * Support for dynamic overlays in link_selections (#4683)
  * Allow clashing Param stream contents (#4677)
  * Ensured pandas does not convert times to UTC (#4711)
  + Removed all use of cyordereddict (#4620)
  * Testing infrastructure moved to GH Actions (#4592)
  Bug fixes:
  * Ensure RangeXY returns x/y ranges in correct order (#4665)
    (#4665)
  * Fix datashader instability with Plotly by disabling padding
    for RGB elements (#4705)
  * Various Dask and cuDF histogram fixes (#4691)
  * Fix handling of custom matplotlib and bokeh colormaps (#4693)
  * Fix cuDF values implementation (#4687)
  * Fixed range calculation on HexTiles (#4689)
  * Use PIL for RGB.load_image (#4639)
  Documentation:
  * Clarified data types accepted by Points (#4430)
  * Updated Introduction notebook (#4682)
  * Fixed releases urls (#4672)
  Compatibility:
  * Warning when there are multiple kdims on Chart elements
    (#4710)
  * Set histogram normed option to False by default (#4258)
  * The default colormap in holoviews is now 'kbc_r' instead of
    'fire'; see issue #3500 for details. This change was made
    mainly because the highest value of the fire colormap is
    white, which meant data was often not visible against a
    white background. To restore the old behavior you can set
    hv.config.default_cmap='fire', which you can do via the
    extension e.g. hv.extension('bokeh',
    config=dict(default_cmap='fire')). There is also
    hv.config.default_gridded_cmap which you can set to 'fire'
    if you wish to use the old colormap for the Raster, Image
    and QuadMesh element types. The default HeatMap colormap has
    also been set to 'kbc_r' for consistency and can be set back
    to the old value of 'RdYlBu_r' via
    hv.config.default_heatmap_cmap.
- refresh remove_nose.patch
- drop remove-cyordereddict.patch
- fix test discovery gh#holoviz/holoviews#4621
  * skip failing tests
* Thu Sep 17 2020 Matej Cepl <mcepl@suse.com>
- Add remove-cyordereddict.patch to remove use of cyordereddict,
  which has been declared obsolete even by its upstream
  (gh#holoviz/holoviews#4620).
- Add remove_nose.patch to remove last residues of using nose
  (gh#holoviz/holoviews#4621).
- Tests are enabled again.
* Wed Jun 24 2020 Todd R <toddrme2178@gmail.com>
- update to version 1.13.3
  + Enhancements:
  * Expose center as an output rendering option (#4365)
  * Configurable throttling schemes for linked streams on the server (#4372)
  * Add support for lasso tool in linked selections (#4362)
  * Add support for NdOverlay in linked selections (#4481)
  * Add support for unwatching on Params stream (#4417)
  * Optimizations for the cuDF interface (#4436)
  * Add support for by aggregator in datashader operations (#4438)
  * Add support for cupy and dask histogram and box-whisker calculations (#4447)
  * Allow rendering HoloViews output as an ipywidget (#4404)
  * Allow DynamicMap callback to accept key dimension values as variable kwargs (#4462)
  * Delete toolbar by default when rendering bokeh plot to PNG (#4422)
  * Ensure Bounds and Lasso events only trigger on mouseup (#4478)
  + Bug fixes:
  * Eliminate circular references to allow immediate garbage collection (#4368, #4377)
  * Allow bytes as categories (#4392)
  * Fix handling of zero as log colormapper lower bound (#4383)
  * Do not compute data ranges if Dimension.values is supplied (#4416)
  * Fix RangeXY updates when zooming on only one axis (#4413)
  * Ensure that ranges do not bounce when data_aspect is set (#4431)
  * Fix bug specifying a rotation for Box element (#4460)
  * Fix handling of datetimes in bokeh RectanglesPlot (#4461)
  * Fix bug normalizing ranges across multiple plots when framewise=True (#4450)
  * Fix bug coloring adjoined histograms (#4458)
  * Fix issues with ranges bouncing when PlotSize stream is attached (#4480)
  * Fix bug with hv.extension(inline=False) (#4491)
  * Handle missing categories on split Violin plot (#4482)
* Sat Apr 11 2020 Arun Persaud <arun@gmx.de>
- update to version 1.13.2:
  * Enhancements:
    + Add PressUp and PanEnd streams (#4334)
  * Bug fixes:
    + Fix regression in single node Sankey computation (#4337)
    + Fix color and alpha option on bokeh Arrow plot (#4338)
    + Fix undefined JS varaibles in various bokeh links (#4341)
    + Fix matplotlib >=3.2.1 deprecation warnings (#4335)
    + Fix handling of document in server mode (#4355)
* Sat Mar 28 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * remove sed commands that modified setup.py (lines not in setup.py
    anymore)
  * require pyct for building
- update to version 1.13.1:
  * Enhancements:
    + Add option to set Plotly plots to responsive (#4319)
    + Unified datetime formatting in bokeh hover info (#4318)
    + Allow using dim expressions as accessors (#4311)
    + Add explicit .df and .xr namespaces to dim expressions to allow
    using dataframe and xarray APIs (#4320)
    + Allow defining clim which defines only upper or lower bound and
    not both (#4314)
  * Bug fixes:
    + Fix regression in Overlay.relabel that occurred in 1.12.3
    resulting in relabeling of contained elements by default (#4246)
    + Fix bug when updating bokeh Arrow elements (#4313)
  * Compatibility:
    + Fix compatibility with Bokeh 2.0.1 (#4308)
  * Documentation:
    + Update API reference manual (#4316)
- changes from version 1.13.0:
  * Major features:
    + Add link_selection to make custom linked brushing simple (#3951)
    + link_selection builds on new support for much more powerful
    data-transform pipelines: new Dataset.transform method (#237,
    [#3932]), dim expressions in Dataset.select (#3920), arbitrary
    method calls on dim expressions (#4080), and Dataset.pipeline
    and Dataset.dataset properties to track provenance of data
    + Add Annotators to allow easily drawing, editing, and annotating
    visual elements (#1185)
    + Completely replaced custom Javascript widgets with Panel-based
    widgets allowing for customizable layout (#84, #805)
    + Add HSpan, VSpan, Slope, Segments and Rectangles elements
    (#3510, #3532, #4000)
    + Add support for cuDF GPU dataframes, cuPy backed xarrays, and
    GPU datashading (#3982)
  * Other features
    + Add spatialpandas support and redesigned geometry interfaces for
    consistent roundtripping (#4120)
    + Support GIF rendering with Bokeh and Plotly backends (#2956,
    [#4017])
    + Support for Plotly Bars, Bounds, Box, Ellipse, HLine, Histogram,
    RGB, VLine and VSpan plots
    + Add UniformNdMapping.collapse to collapse nested datastructures
    (#4250)
    + Add CurveEdit and SelectionXY streams (#4119, #4167)
    + Add apply_when helper to conditionally apply operations (#4289)
    + Display Javascript callback errors in the notebook (#4119)
    + Add support for linked streams in Plotly backend to enable rich
    interactivity (#3880, #3912)
  * Enhancements:
    + Support for packed values dimensions, e.g. 3D RGB/HSV arrays
    (#550, #3983)
    + Allow selecting/slicing datetimes with strings (#886)
    + Support for datashading Area, Spikes, Segments and Polygons
    (#4120)
    + HeatMap now supports mixed categorical/numeric axes (#2128)
    + Use __signature__ to generate .opts tab completions (#4193)
    + Allow passing element-specific keywords through datashade and
    rasterize (#4077) (#3967)
    + Add per_element flag to .apply accessor (#4119)
    + Add selected plot option to control selected glyphs in bokeh
    (#4281)
    + Improve default Sankey node_padding heuristic (#4253)
    + Add hooks plot option for Plotly backend (#4157)
    + Support for split Violin plots in bokeh (#4112)
  * Bug fixes:
    + Fixed radial HeatMap sizing issues (#4162)
    + Switched to Panel for rendering machinery fixing various export
    issues (#3683)
    + Handle updating of user supplied HoverTool in bokeh (#4266)
    + Fix issues with single value datashaded plots (#3673)
    + Fix legend layout issues (#3786)
    + Fix linked axes issues with mixed date, categorical and numeric
    axes in bokeh (#3845)
    + Fixed handling of repeated dimensions in PandasInterface (#4139)
    + Fixed various issues related to widgets (#3868, #2885, #1677,
    [#3212], #1059, #3027, #3777)
  * Library compatibility:
    + Better support for Pandas 1.0 (#4254)
    + Compatibility with Bokeh 2.0 (#4226)
  * Migration notes:
    + Geometry .iloc now indexes by geometry instead of by
    datapoint. Convert to dataframe or dictionary before using .iloc
    to access individual datapoints (#4104)
    + Padding around plot elements is now enabled by default, to
    revert set hv.config.node_padding = 0 (#1090)
    + Removed Bars group_index and stack_index options, which are now
    controlled using the stacked option (#3985)
    + .table is deprecated; use .collapse method instead and cast to
    Table (#3985)
    + HoloMap.split_overlays is deprecated and is now a private method
    (#3985)
    + Histogram.edges and Histogram.values properties are deprecated;
    use dimension_values (#3985)
    + Element.collapse_data is deprecated; use the container's
    .collapse method instead (#3985)
    + hv.output filename argument is deprecated; use hv.save instead
    (#3985)
* Sun Nov 24 2019 Arun Persaud <arun@gmx.de>
- update to version 1.12.7:
  * This a very minor hotfix release fixing an important bug related
    to axiswise normalization between plots.
  * Enhancements:
    + Add styles attribute to PointDraw stream for consistency with
    other drawing streams (#3819)
  * Bug fixes:
    + Fixed shared_axes/axiswise regression (#4097)
* Thu Oct 24 2019 Todd R <toddrme2178@gmail.com>
- update to version 1.12.6:
  + Enhancements:
  * Ensured that shared_axes option on layout plots is respected across backends
  * Allow plotting partially irregular (curvilinear) mesh
  * Add support for dependent functions in dynamic operations
  * Add support for fast QuadMesh rasterization with datashader >= 0.8
  * Allow passing Panel widgets as operation parameter
  + Bug fixes:
  * Fixed issue rounding datetimes in Curve step interpolation
  * Fix resampling of categorical colorcet colormaps
  * Ensure that changing the Stream source deletes the old source
  * Ensure missing hover tool does not break plot
  * Ensure .apply work correctly on HoloMaps
  * Ensure Grid axes are always aligned in bokeh
  * Fix hover tool on Image and Raster plots with inverted axis
  * Ensure that DynamicMaps are still linked to streams after groupby
  * Using hv.renderer no longer switches backends
  * Ensure that Points/Scatter categorizes data correctly when axes are inverted
  * Fixed error creating legend for matplotlib Image artists
  * Ensure that unqualified Options objects are supported
  * Fix bounds check when constructing Image with ImageInterface
  * Ensure elements cannot be constructed with wrong number of columns
  * Ensure streaming data works on bokeh server
  + Compatibility:
  * Ensure HoloViews is fully compatible with xarray 0.13.0
  * Ensure that deprecated matplotlib 3.1 rcparams do not warn
  * Ensure compatibility with new legend options in bokeh 1.4.0
* Sat Aug 31 2019 Arun Persaud <arun@gmx.de>
- update to version 1.12.5:
  * Compatibility:
    + The DaskInterface no longer attempts to import dask.dataframe
    unless it is already imported (#3900)
    + Scatter3D matplotlib rendering no longer errors with matplotlib
    >= 3.1 (#3898)
  * Bug fixes:
    + Fixed bug converting datetime64 to datetime for dates <1970
    (#3879)
- changes from version 1.12.4:
  * Enhancements:
    + Add numpy log to dim transforms (#3731)
    + Make Buffer stream following behavior togglable (#3823)
    + Added internal methods to access dask arrays and made histogram
    operation operate on dask arrays (#3854)
    + Optimized range finding if Dimension.range is set (#3860)
    + Add ability to use functions annotated with param.depends as
    DynamicMap callbacks (#3744)
  * Bug fixes:
    + Fixed handling datetimes on Spikes elements (#3736)
    + Fix graph plotting for unsigned integer node indices (#3773)
    + Fix sort=False on GridSpace and GridMatrix (#3769)
    + Fix extent scaling on VLine/HLine annotations (#3761)
    + Fix BoxWhisker to match convention (#3755)
    + Improved handling of custom array types (#3792)
    + Allow setting cmap on HexTiles in matplotlib (#3803)
    + Fixed handling of data_aspect in bokeh backend (#3848, #3872)
    + Fixed legends on bokeh Path plots (#3809)
    + Ensure Bars respect xlim and ylim (#3853)
    + Allow setting Chord edge colors using explicit colormapping
    (#3734)
    + Fixed bug in decimate operation (#3875)
  * Compatibility:
    + Improve compatibility with deprecated matplotlib rcparams
    (#3745, #3804)
  * Backwards incompatible changes:
    + Unfortunately due to a major mixup the data_aspect option added
    in 1.12.0 was not correctly implemented and fixing it changed
    its behavior significantly (inverting it entirely in some
    cases).
    + A mixup in the convention used to compute the whisker of a
    box-whisker plots was fixed resulting in different results going
    forward.
* Tue May 28 2019 Todd R <toddrme2178@gmail.com>
- update to version 1.12.3
  * Bug fixes:
  * Fixed regression causing unhashable data to cause errors in streams
  * Ensure that hv.help handles non-HoloViews objects
  * Ensure that DataLink handles data containing NaNs
  * Ensure that bokeh backend handles Cycle of markers
  * Fix for using opts method on DynamicMap
  * Ensure that bokeh backend handles DynamicMaps with variable length
    NdOverlay
  * Fix default width/height setting for HeatMap
  * Ensure that dask imports handle modularity
  * Fixed regression in xarray data interface
  * Ensure that RGB hover displays the integer RGB value
  * Ensure that param streams handle subobjects
- update to version Version 1.12.2
  + Enhancements:
  * Add styles argument to draw tool streams to allow cycling colors
  and other styling when drawing glyphs
  * Add ability to define alpha on (data)shade operation
  * Ensure that categorical plots respect Dimension.values order
  + Compatibility:
  * Compatibility with Plotly 3.8
  + Bug fixes:
  * Ensure that bokeh server plot updates have the exclusive Document
    lock
  * Ensure that Dimensioned streams are inherited on `__mul__`
  * Ensure that bokeh hover tooltips are updated when dimensions change
  * Fix DynamicMap.event method for empty streams
  * Fixed handling of datetimes on Path plots
  * Ensure that resampling operations do not cause event loops
  + Backward compatibility:
  * Added color cycles on Violin and BoxWhisker elements due to earlier
    regression
* Mon Apr 22 2019 Todd R <toddrme2178@gmail.com>
- update to version 1.12.1
  * Add support for passing in parameter instances as streams
- update to version 1.12.0
  + Features:
  * New plot options for controlling layouts including a responsive mode
    as well as improved control over aspect using the newly updated bokeh
    layout engine.
  * Added a succinct and powerful way of creating DynamicMaps from
    functions and methods via the new `.apply` method.
  + Enhancements:
  * Added a number of new plot options including a clabel param for
    colorbars, exposed Sankey font size and added a radius for bokeh
    nodes.
  * Switched notebook output to use an HTML mime bundle instead of
    separate HTML and JS components.
  * Improved support for style mapping constant values via
    `dim.categorize`
  + Bug fixes:
  * Fixes for colorscales and colorbars
  * Other miscellaneous fixes
- Update to version 1.11.3
  + Bug fixes:
  * All unused Options objects are now garbage collected fixing the last
    memory leak
  * Ensured updating of size on matplotlib charts does not error
  * Fix casting of datetimes on dask dataframes
  * Ensure that calling redim does not break streams and links
  * Ensure that matplotlib polygon plots close the edge path
  * Fixed bokeh ArrowPlot error handling colorbars
  * Fixed bug in angle conversion on the VectorField if invert_axes
  * Ensure that all non-Annotation elements support empty constructors
  * Fixed bug handling out-of-bounds errors when using tap events on
    datetime axis
  + Enhancements:
  * Apply Labels element offset using a bokeh transform allowing Labels
    element to share data with original data
  * Allow using datetimes in xlim/ylim/zlim
  * Optimized rendering of TriMesh wireframes
  * Add support for datetime formatting when hovering on Image/Raster
  * Added Tiles element from GeoViews
* Sat Feb  2 2019 Arun Persaud <arun@gmx.de>
- update to version 1.11.2:
  * Bug fixes:
    + Compatibility with pandas 0.24.0 release (#3433)
    + Fixed timestamp selections on streams (#3427)
    + Fixed persisting options during clone on Overlay (#3435)
    + Ensure cftime datetimes are displayed as a slider (#3413)
  * Enhancements:
    + Allow defining hook on backend load (#3429)
    + Improvements for handling graph attributes in
    Graph.from_networkx (#3432)
* Tue Jan 22 2019 Todd R <toddrme2178@gmail.com>
- Disable tests again, they still aren't working.
- Fix incomplete conversion from wheel to tar.gz
* Mon Jan 21 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to normal tarball and enable tests
* Sun Jan 20 2019 Arun Persaud <arun@gmx.de>
- update to version 1.11.1:
  * Bug fixes:
    + Fixed bug plotting adjoined histograms in matplotlib (#3377)
    + Fixed bug updating bokeh RGB alpha value (#3371)
    + Handled issue when colorbar limits were equal in bokeh (#3382)
    + Fixed bugs plotting empty Violin and BoxWhisker elements (#3397,
    [#3405])
    + Fixed handling of characters that have no uppercase on Layout
    and Overlay objects ((#3403)
    + Fixed bug updating Polygon plots in bokeh (#3409)
  * Enhancements:
    + Provide control over gridlines ticker and mirrored axis ticker
    by default (#3398)
    + Enabled colorbars on CompositePlot classes such as Graphs,
    Chords etc. (#3397)
    + Ensure that xarray backend retains dimension metadata when
    casting element (#3401)
    + Consistently support clim options (#3382)
  * Documentation:
    + Completed updates from .options to .opts API in the
    documentation
    ([#3364]((https://github.com/ioam/holoviews/pull/3364), #3367
* Tue Jan  8 2019 Todd R <toddrme2178@gmail.com>
- update to version 1.11.0
  + Features:
  * Generalized support for style mapping using `dim` transforms
    ([2152](https://github.com/ioam/holoviews/pull/2152))
  * Added alternative to opts magic with tab-completion
    ([#3173](https://github.com/ioam/holoviews/pull/3173))
  * Added support for Polygons with holes and improved contours
    operation ([#3092](https://github.com/ioam/holoviews/pull/3092))
  * Added support for Links to express complex interactivity in JS
    ([#2832](https://github.com/ioam/holoviews/pull/2832))
  * Plotly improvements including support for plotly 3.0
    ([#3194](https://github.com/ioam/holoviews/pull/3194)), improved
    support for containers
    ([#3255](https://github.com/ioam/holoviews/pull/3255)) and support
    for more elements
    ([#3256](https://github.com/ioam/holoviews/pull/3256))
  * Support for automatically padding plots using new `padding` option
    ([#2293](https://github.com/ioam/holoviews/pull/2293))
  * Added `xlim`/`ylim` plot options to simplify setting axis ranges
    ([#2293](https://github.com/ioam/holoviews/pull/2293))
  * Added `xlabel`/`ylabel` plot options to simplify overriding axis
    labels ([#2833](https://github.com/ioam/holoviews/issues/2833))
  * Added `xformatter`/`yformatter` plot options to easily override tick
    formatter ([#3042](https://github.com/ioam/holoviews/pull/3042))
  * Added `active_tools` options to allow defining tools to activate on
    bokeh plot initialization
    ([#3251](https://github.com/ioam/holoviews/pull/3251))
  * Added `FreehandDraw` stream to allow freehand drawing on bokeh plots
    ([#2937](https://github.com/ioam/holoviews/pull/2937))
  * Added support for `cftime` types for dates which are not supported
    by standard datetimes and calendars
    ([#2728](https://github.com/ioam/holoviews/pull/2728))
  * Added top-level `save` and `render` functions to simplify exporting
    plots ([#3134](https://github.com/ioam/holoviews/pull/3134))
  * Added support for updating Bokeh bokeh legends
    ([#3139](https://github.com/ioam/holoviews/pull/3139))
  * Added support for indicating directed graphs with arrows
    ([#2521](https://github.com/ioam/holoviews/issues/2521))
  + Enhancements:
  * Improved import times
    ([#3055](https://github.com/ioam/holoviews/pull/3055))
  * Adopted Google style docstring and documented most core methods and
    classes ([#3128](https://github.com/ioam/holoviews/pull/3128)
  + Bug fixes:
  * GIF rendering fixed under Windows
    ([#3151](https://github.com/ioam/holoviews/issues/3151))
  * Fixes for hover on Path elements in bokeh
    ([#2472](https://github.com/ioam/holoviews/issues/2427),
    [#2872](https://github.com/ioam/holoviews/issues/2872))
  * Fixes for handling TriMesh value dimensions on rasterization
    ([#3050](https://github.com/ioam/holoviews/pull/3050))
  + Deprecations:
  * `finalize_hooks` renamed to `hooks`
    ([#3134](https://github.com/ioam/holoviews/pull/3134))
  * All `*_index` and related options are now deprecated including
    `color_index`, `size_index`, `scaling_method`, `scaling_factor`,
    `size_fn` ([#2152](https://github.com/ioam/holoviews/pull/2152))
  * Bars `group_index`, `category_index` and `stack_index` are deprecated in
    favor of stacked option
    ([#2828](https://github.com/ioam/holoviews/issues/2828))
  * iris interface was moved to GeoViews
    ([#3054](https://github.com/ioam/holoviews/pull/3054))
  * Top-level namespace was cleaned up
    ([#2224](https://github.com/ioam/holoviews/pull/2224))
  * `ElementOpration`, `Layout.display` and `mdims` argument to `.to`
    now fully removed
    ([#3128](https://github.com/ioam/holoviews/pull/3128))
  * `Element.mapping`, `ItemTable.values`, `Element.table`,
    `HoloMap.split_overlays`, `ViewableTree.from_values`,
    `ViewableTree.regroup` and `Element.collapse_data` methods now
    marked for deprecation
    ([#3128](https://github.com/ioam/holoviews/pull/3128))
- Switch to wheel
* Tue Oct 30 2018 Arun Persaud <arun@gmx.de>
- update to version 1.10.8:
  * Enhancements:
    + Add support for labels, choord, hextiles and area in .to
    interface (#2924)
    + Allow defining default bokeh themes as strings on Renderer
    (#2972)
    + Allow specifying fontsize for categorical axis ticks in bokeh
    (#3047)
    + Allow hiding toolbar without disabling tools (#3074)
    + Allow specifying explicit colormapping on non-categorical data
    (#3071)
    + Support for displaying xarray without explicit coordinates
    (#2968)
  * Fixes:
    + Ensured that objects are garbage collected when using linked
    streams (#2111)
    + Allow dictionary data to reference values which are not
    dimensions (#2855, #2859)
    + Fixes for zero and non-finite ranges in datashader operation
    (#2860, #2863, #2869)
    + Fixes for CDSStream and drawing tools on bokeh server (#2915)
    + Fixed issues with nans, datetimes and streaming on Area and
    Spread elements (#2951, c55b044)
    + General fixes for datetime handling (#3005, #3045, #3075)
    + Fixed handling of curvilinear and datetime coordinates on
    QuadMesh (#3017, #3081)
    + Fixed issue when inverting a shared axis in bokeh (#3083)
    + Fixed formatting of values in HoloMap widgets (#2954)
    + Fixed setting fontsize for z-axis label (#2967)
  * Compatibility:
    + Suppress warnings about rcParams in matplotlib 3.0 (#3013,
    [#3058], #3104)
    + Fixed incompatibility with Python <=3.5 (#3073)
    + Fixed incompatibility with bokeh >=1.0 (#3051)
  * Documentation:
    + Completely overhauled the FAQ (#2928, #2941, #2959, #3025)
* Tue Oct  9 2018 Todd R <toddrme2178@gmail.com>
- Requires pyviz-comms
* Thu Jul 12 2018 arun@gmx.de
- update to version 1.10.7:
  * Fix datashader aggregation of empty and zero-range data (#2860,
    [#2863])
  * Disable validation for additional, non-referenced keys in the
    DictInterface (#2860)
  * Fixed frame lookup for non-overlapping dimensions (#2861)
  * Fixed ticks on log Colorbar if low value <= 0 (#2865)
* Sun Jul  1 2018 arun@gmx.de
- specfile:
  * removed devel requirement
  * use %%{python_sitelib}/holoview* insted of  %%{python_sitelib}/* in %%files
* Sun Jul  1 2018 arun@gmx.de
- update to version 1.10.6:
  * Enhancements:
    + Added the ability to specify color intervals using the
    color_levels plot options (#2797)
    + Allow defining port and multiple websocket origins on
    BokehRenderer.app (#2801)
    + Support for datetimes in Curve step interpolation (#2757)
    + Add ability to mute legend by default (#2831)
    + Implemented ability to collapse and concatenate gridded data
    (#2762)
    + Add support for cumulative histogram and explicit bins (#2812)
  * Fixes:
    + Dataset discovers multi-indexes on dask dataframes (#2789)
    + Fixes for datashading NdOverlays with datetime axis and data
    with zero range (#2829, #2842)
* Sun Jun 24 2018 arun@gmx.de
- update to version 1.10.5:
  * Enhancements:
    + Graph.from_networkx now extracts node and edge attributes from
    networkx graphs (#2714)
    + Added throttling support to scrubber widget (#2748)
    + histogram operation now works on datetimes (#2719)
    + Legends on NdOverlay containing overlays now supported (#2755)
    + Dataframe indexes may now be referenced in .to conversion
    (#2739)
    + Reindexing a gridded Dataset without arguments now behaves
    consistently with NdMapping types and drops scalar dimensions
    making it simpler to drop dimensions after selecting (#2746)
  * Fixes:
    + Various fixes for QuadMesh support including support for
    contours, nan coordinates and inverted coordinates (#2691,
    [#2702], #2771)
    + Fixed bugs laying out complex layouts in bokeh (#2740)
    + Fix for adding value dimensions to an xarray dataset (#2761
  * Compatibility:
    + Addressed various deprecation warnings generated by pandas 0.23
    (#2699, #2725, #2767)
- changes from version 1.10.4:
  * Enhancement:
    + Allow setting alpha on Image/RGB/HSV and Raster types in bokeh
    (#2680)
  * Fixes:
    + Fixed bug running display multiple times in one cell (#2677)
    + Avoid sending hover data unless explicitly requested (#2681)
    + Fixed bug slicing xarray with tuples (#2674)
* Thu May 10 2018 arun@gmx.de
- update to version 1.10.3:
  * Enhancement:
    + The dimensions of elements may now be changed allowing updates
    to axis labels and table column headers (#2666)
  * Fixes:
    + Fix for labelled plot option (#2643)
    + Optimized initialization of dynamic plots specifying a large
    parameter space (#2646)
    + Fixed unicode and reversed axis slicing issues in
    XArrayInterface (#2658, #2653)
    + Fixed widget sorting issues when applying dynamic groupby
    (#2641)
  * API:
    + The PlotReset reset parameter was renamed to resetting to avoid
    clash with a method (#2665)
    + PolyDraw tool data parameter now always indexed with 'xs' and
    'ys' keys for consistency (#2650)
* Tue May  1 2018 toddrme2178@gmail.com
- Update to 1.10.2
  + Enhancement:
  * Exposed Image hover functionality for upcoming bokeh 0.12.16 release
    ([#2625](https://github.com/ioam/holoviews/pull/2625))
  + Fixes:
  * Minor fixes for newly introduced elements and plots including Chord
    ([#2581](https://github.com/ioam/holoviews/issues/2581)) and
    RadialHeatMap
    ([#2610](https://github.com/ioam/holoviews/issues/2610)
  * Fixes for .options method including resolving style and plot option
    clashes ([#2411](https://github.com/ioam/holoviews/issues/2411)) and
    calling it without arguments
    ([#2630](https://github.com/ioam/holoviews/pull/2630))
  * Fixes for IPython display function
    ([#2587](https://github.com/ioam/holoviews/issues/2587)) and
    display_formats
    ([#2592](https://github.com/ioam/holoviews/issues/2592))
  + Deprecations:
  * BoxWhisker and Bars ``width`` bokeh style options and Arrow
    matplotlib ``fontsize`` option are deprecated
    ([#2411](https://github.com/ioam/holoviews/issues/2411))
* Tue Apr 24 2018 toddrme2178@gmail.com
- Update to 1.10.1
  * Fixed static HTML export of notebooks (#2574)
  * Ensured Chord element allows recurrent edges (#2583)
  * Restored behavior for inferring key dimensions order from XArray Dataset (#2579)
  * Fixed Selection1D stream on bokeh server after changes in bokeh 0.12.15 (#2586)
* Wed Apr 18 2018 toddrme2178@gmail.com
- Update to 1.10.0
  + JupyterLab support:
  * Full compatibility with JupyterLab when installing the jupyterlab_holoviews extension (#687)
  + New components:
  * Added Sankey element to plot directed flow graphs (#1123)
  * Added TriMesh element and datashading operation to plot small and large irregular meshes (#2143)
  * Added a Chord element to draw flow graphs between different nodes (#2137, #2143)
  * Added HexTiles element to plot data binned into a hexagonal grid (#1141)
  * Added Labels element to plot a large number of text labels at once (as data rather than as annotations) (#1837)
  * Added Div element to add arbitrary HTML elements to a Bokeh layout (#2221)
  * Added PointDraw, PolyDraw, BoxEdit, and PolyEdit streams to allow drawing, editing, and annotating glyphs on a Bokeh plot, and syncing the resulting data to Python (#2268)
  + Features:
  * Added radial HeatMap option to allow plotting heatmaps with a cyclic x-axis (#2139)
  * All elements now support declaring bin edges as well as centers allowing Histogram and QuadMesh to become first class Dataset types (#547)
  * When using widgets, their initial or default value can now be set via the Dimension.default parameter (#704)
  * n-dimensional Dask arrays are now supported directly via the gridded dictionary data interface (#2305)
  + Enhancements:
  * Improvements to exceptions (#1127)
  * Toolbar position and merging (via a new merge_toolbar option) can now be controlled for Layout and Grid plots (#1977)
  * Bokeh themes can now be applied at the renderer level (#1861)
  * Dataframe and Series index can now be referenced by name when constructing an element (#2000)
  * Option-setting methods such as .opts, .options and hv.opts now allow specifying the backend instead of defaulting to the current backend (#1801)
  * Handled API changes in streamz 0.3.0 in Buffer stream (#2409)
  * Supported GIF output on windows using new Matplotlib pillow animation support (#385)
  * Provided simplified interface to rasterize most element types using datashader (#2465)
  * Bivariate element now support levels as a plot option (#2099)
  * NdLayout and GridSpace now consistently support * overlay operation (#2075)
  * The Bokeh backend no longer has a hard dependency on Matplotlib (#829)
  * DynamicMap may now return (Nd)Overlay with varying number of elements (#1388)
  * In the notebook, deleting or re-executing a cell will now delete the plot and clean up any attached streams (#2141)
  * Added color_levels plot option to set discrete number of levels during colormapping (#2483)
  + Fixes:
  * Layout and Overlay objects no longer create lower-case nodes on attribute access (#2331)
  * Dimension.step now correctly respects both integer and float steps (#1707)
  * Fixed timezone issues when using linked streams on datetime axes (#2459)
  + Changes affecting backwards compatibility:
  * Image elements now expect and validate regular sampling (#1869); for genuinely irregularly sampled data QuadMesh should be used.
  * Tabular elements will no longer default to use ArrayInterface, instead preferring pandas and dictionary data formats (#1236)
  * Cycle/Palette values are no longer zipped together; instead they now cycle independently (#2333)
  * The default color Cycle was expanded to provide more unique colors (#2483)
  * Categorical colormapping was made consistent across backends, changing the behavior of categorical Matplotlib colormaps (#2483)
  * Disabled auto-indexable property of the Dataset baseclass, i.e. if a single column is supplied no integer index column is added automatically (#2522)
* Sun Mar  4 2018 jengelh@inai.de
- Ensure neutrality of description. Say some more about the
  implementation.
* Fri Mar  2 2018 arun@gmx.de
- update to version 1.9.5:
  * Enhancements:
    + Added .options method for simplified options setting. (#2306)
  * Fixes:
    + Allow plotting bytes datausing the bokeh backend in python3
    (#2357)
    + Allow .range to work on data with heterogeneous types in Python
    3 (#2345)
    + Fixed bug streaming data containing datetimes using
    bokeh>=0.12.14 (#2383)
* Thu Mar  1 2018 toddrme2178@gmail.com
- Update to Version 1.9.4
  + Fixes:
  * Compatibility with recent versions of dask and pandas
  * Fixed bug referencing columns containing non-alphanumeric characters
    in bokeh Tables
  * Fixed issue in regrid operation
  * Fixed issue when using datetimes with datashader when processing
    ranges
- Update to Version 1.9.3
  + Enhancements:
  * Optimized rendering of stream based OverlayPlots
  * Added ``merge_toolbars`` and ``toolbar`` options to control
    toolbars on ``Layout`` and Grid plots
  * Optimized rendering of ``VectorField``
  * Improvements to documentation
  * Improved bokeh ``Table`` formatting
  * Added support for handling datetime.date types
  * Add support for pre- and post-process hooks on operations
  + Fixes:
  * Fix for bokeh server widgets
  * Fix using event based streams on bokeh server
  * Switched to drawing ``Distribution``, ``Area`` and ``Spread``
    using patch glyphs in bokeh fixing legends
  * Fixed categorical coloring of ``Polygons``/``Path`` elements in
    matplotlib
  * Fixed bug computing categorical datashader aggregates
  * Allow using ``Empty`` object in ``AdjointLayout``
  + API Changes:
  * Renamed ``Trisurface`` to ``TriSurface`` for future consistency
- Update to Version 1.9.2
  + Enhancements:
  * Improved the Graph element, optimizing the constructor
    and adding support for defining a `edge_color_index`
  * Added support for adding jitter to bokeh Scatter and Points plots
  + Fixes:
  * Ensure dimensions, group and label are inherited when casting
    Image to QuadMesh
  * Handle compatibility for bokeh version >= 0.12.11
  * Fixed broken bokeh ArrowPlot
  * Fixed Pointer based streams on datetime axes
  * Allow constructing and plotting of empty Distribution and
    Bivariate elements
  * Added support for hover info on bokeh BoxWhisker plots
  * Fixed bug attaching streams to (Nd)Overlay types
- Update to Version 1.9.1
  + Enhancements:
  * Exposed min_alpha parameter on datashader shade and datashade
    operations
  + Fixes:
  * Fixed broken bokeh server linked stream throttling
  * Fixed bug in bokeh callbacks preventing linked streams using
    bokeh's on_event callbacks from working
  * Fixed insufficient validation issue for Image and bugs when
    applying regrid operation to xarray based Images
  * Fixed handling of dimensions and empty elements in univariate_kde
    and bivariate_kde operations
- Update to Version 1.9.0
  + Features:
  * The kdim and vdim keyword arguments are now positional making the
    declaration of elements less verbose (e.g. Scatter(data, 'x',
    'y'))
  * Added Graph, Nodes, and EdgePaths elements adding support for
    plotting network graphs
  * Added datashader based regrid operation for fast Image and RGB
    regridding
  * Added support for binary transport when plotting with bokeh,
    providing huge speedups for dynamic plots
  * Added Pipe and Buffer streams for streaming data support
  * Add support for datetime axes on Image, RGB and when applying
    datashading and regridding operations
  * Added Distribution and Bivariate as first class elements which can
    be plotted with matplotlib and bokeh without depending on seaborn
  * Completely overhauled support for plotting geometries with Path,
    Contours and Polygons elements including support for coloring
    individual segments and paths by value
  + Enhancements:
  * Add support for adjoining all elements on matplotlib plots
  * Improved exception handling for data interfaces
  * Add groupby argument to histogram operation
  * Add support for reverse sort on Dataset elements
  * Added support for invert_x/yaxis on all elements
  + Fixes:
  * Fixed a bug in matplotlib causing the first frame in gif and mp4
    getting stuck
  * Fixed various issues with support for new nested categorical axes
    in bokeh
  * A large range of other bug fixes too long to list here.
  + Changes affecting backwards compatibility:
  * The contours operation no longer overlays the contours on top of
    the supplied Image by default and returns a single
    Contours/Polygons rather than an NdOverlay of them
  * The values of the Distribution element should now be defined as a
    key dimension
  * The seaborn interface was removed in its entirety being replaced
    by first class support for statistics elements such as
    Distribution and Bivariate
  * Since kdims and vdims can now be passed as positional arguments
    the bounds argument on Image is no longer positional.
  * The datashade and shade cmap was reverted back to blue due to issues
    with the fire cmap against a white background.
  * Dropped all support for bokeh versions older than 0.12.10
  * histogram operation now returns Histogram elements with less
    generic value dimension and customizable label
- Update to Version 1.8.4
  + Fixes:
  * Fixes to register BoundsXY stream.
  * Fix for Bounds streams on bokeh server.
  * Compatibility with matplotlib 2.1
  * Fixed bug in scrubber widget and support for scrubbing discrete
    DynamicMaps
  * Various fixes for compatibility with bokeh 0.12.9
  * Fixes for setting QuadMesh ranges.
  * Fixes for inverting Image/RGB/Raster axes in bokeh.
- Disable unit tests.  They freeze.
* Thu Aug 17 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to Version 1.8.3
  + Features:
  * Add support for setting the bokeh sizing_mode as a plot option
  + Fixes:
  * Handle StopIteration on DynamicMap correctly.
  * Fix bug with linked streams on empty source element
  * Compatibility with latest datashader 0.6.0 release
  * Fixed missing HTML closing tag in extension
  * Various fixes and improvements for documentation
- Update to Version 1.8.2
  + Feature:
  * Added support for groupby to histogram operation.
  + Fixes:
  * Fixed problem with HTML export due to new extension logos.
  * Replaced deprecated ``__call__`` usage with opts method throughout codebase.
  * Fixed pip installation.
  * Fixed miscellaneous bugs
- Update to Version 1.8.1
  + Feature:
  * All enabled plotting extension logos now shown
  + Fixes:
  * Updated search ordering when looking for holoviews.rc
  * Fixed lower bound inclusivity bug when no upper bound supplied
  * Raise SkipRendering error when plotting nested layouts
  * Added safety margin for grid axis constraint issue
  * Fixed bug when using +framewise
  * Fixed handling of Spacer models in sparse grid
  * Renamed Bounds to BoundsXY for consistency
  * Fixed bokeh log axes with axis lower bound &lt;=0
  * Set default datashader cmap to fire
  * Set SpikesPlot color index to None by default
  * Documentation fixes
- Update to Version 1.8.0
  + Major features:
  * Completely overhauled the documentation and website
  * Replaced dependency on bkcharts with new Bokeh bar plot
    and bokeh BoxWhisker plot
  * Added support for drawing the `Arrow` annotation in bokeh
  * Added periodic method DynamicMap to schedule recurring events
  * Cleaned up the API for deploying to bokeh server
  * Validation of invalid backend specific options
  * Added utilities and entry points to convert notebooks to scripts
    including magics
  * Added support for rendering to png in bokeh backend
  * Made matplotlib and bokeh styling more consistent and dropped custom
    matplotlib rc file
  * Added `iloc` and `ndloc` method to allow integer based indexing on
    tabular and gridded datasets
  * Added option to restore case sensitive completion order by setting
    `hv.extension.case_sensitive_completion=True` in python or via
    holoviews.rc file
  + Other new features and improvements:
  * Optimized datashading of `NdOverlay`
  * Expose last `DynamicMap` args and kwargs on Callable
  * Allow colormapping `Contours` Element
  * Add support for fixed ticks with labels in bokeh backend
  * Added a `clim` parameter to datashade controlling the color range
  * Add support for wrapping xarray DataArrays containing dask arrays
  * Added support for aggregating to target `Image` dimensions in
    datashader `aggregate` operation
  * Added top-level hv.extension and `hv.renderer` utilities
  * Added support for `Splines` defining multiple cubic splines in bokeh
  * Add support for redim.label to quickly define dimension labels
  * Add `BoundsX` and `BoundsY` streams
  * Added support for adjoining empty plots
  * Handle zero-values correctly when using `logz` colormapping option
    in matplotlib
  * Define a number of `Cycle` and `Palette` defaults across backends
  * Many other small improvements and fixes
  + Changes affecting backwards compatibility:
  * Renamed `ElementOperation` to `Operation`
  * Removed `stack_area` operation in favor of `Area.stack` classmethod
  * Removed all mpld3 support
  * Added `opts` method on all types, replacing the now-deprecated
    `__call__` syntax to set options
  * Styling changes for both matplotlib and bokeh, which can be reverted
    for a notebook with the `config` option of `hv.extension`. For
    instance, `hv.extension('bokeh', config=dict(style_17=True))`
- Update to Version 1.7.0
  + Major features and improvements:
  * Interactive Streams API
  * Dynamic Callable API
  * Simpler and more powerful DynamicMap
  * Fully general support for Bokeh events
  * Datashader operations
  * Support for Bokeh apps and Bokeh Server
  * Working with renderers interactively outside the notebook
  * Support for Matplotlib 2.0
  * Support for Bokeh 0.12.2, 0.12.3, 0.12.4, and 0.12.5.
  * Many new features for the Bokeh backend: widgets editable, selection
    colors and interactive legends, GridSpace axes,
    categorical axes and colormapping, computing
    plot size, GridSpaces inside Layouts, Layout/Grid
    titles, histogram with live colormapping, colorbars,
    finalize_hooks, labelled and show_frame options, styling
    hover glyphs, hiding legends on BarPlot, VectorField plot,
    Histograms now have same color cycle as mpl.
  * Implemented convenience redim methods to easily set dimension
    ranges, values etc.
  * Made methods on and operations applied to DynamicMap lazy
  * Improved documentation.
  * Improved error handling, including
    re-enabling option system keyword validation.
  * Improved testing.
  + Other new features and improvements:
  * Operations for timeseries, downsample_columns,
    interpolate_curve, and stacked_area.
  * Dataset types can be declared as empty by passing an empty list
  * Plot or style options for Curve interpolation transposing
    layouts, multiple paths, and norm for ColorbarPlot.
  * Improved options inheritance for more intuitive behavior.
  * Image interface providing similar functionality for Image and
    non-Image types (making GridImage obsolete).
  * dask data interface.
  * xarray aggregate/reduce.
  * Indicate color clipping and control clipping colors.
  * Better datetime handling.
  * Gridmatrix diagonal types.
  * log option for histogram operation.
  * Perceptually uniform fire colormap.
  * Support for adjoining overlays.
  * coloring weighted average in SideHistogram.
  * HeatMap allows displaying multiple values on hover.
  * Allow casting Image to QuadMesh.
  * Unused columns are now preserved in gridded groupby.
  * Optimizations and fixes for constructing Layout/Overlay types.
  * DynamicMap fixes.
  * Bokeh-backend fixes including handling of empty frames,
    faster updates, hover tool fixes, and many more.
  * Matplotlib-backend fixes and improvements.
  * Many other small improvements and fixes.
  + Changes affecting backwards compatibility:
  * Automatic coloring and sizing on Points now disabled.
  * Deprecated max\_branches output magic option.
  * Deprecated GridImage.
  * Deprecated NdElement.
  * Deprecated DFrame conversion methods.
  * Banner text removed from notebook\_extension().
  * Bokeh's matplotlib compatibility module removed.
  * ls as matplotlib linestyle alias dropped.
  * mdims argument of conversion interface renamed to groupby.
  * Replaced global alias state with Dimension.label.
  * DynamicMap only update ranges when set to framewise
  * Deprecated DynamicMap sampled, bounded, open and generator modes
  * Layout.display method is now deprecated
  * Layout fix for matplotlib figures with non-square aspects introduced
    in 1.6.2, now enabled by default.
* Mon Oct 17 2016 toddrme2178@gmail.com
- Update to 1.6.2
  * Optimized bokeh event messaging, reducing the average json payload
    by 30-50%% (PR `#807 <https://github.com/ioam/holoviews/pull/807>`_).
  * Fixes for correctly handling NdOverlay types returned by DynamicMaps
    (PR `#814 <https://github.com/ioam/holoviews/pull/814>`_).
  * Added support for datetime64 handling in matplotlib and support for
    datetime formatters on Dimension.type_formatters (PR `#816
    <https://github.com/ioam/holoviews/pull/816>`_).
  * Fixed handling of constant dimensions when slicing xarray datasets
    (PR `#817 <https://github.com/ioam/holoviews/pull/817>`_).
  * Fixed support for passing custom dimensions to iris Datasets (PR
    `#818 <https://github.com/ioam/holoviews/pull/818>`_).
  * Fixed support for add_dimension on xarray interface (PR `#820
    <https://github.com/ioam/holoviews/pull/820>`_).
  * Improved extents computation on matplotlib SpreadPlot (PR `#821
    <https://github.com/ioam/holoviews/pull/821>`_).
  * Bokeh backend avoids sending data for static frames and empty events
    (PR `#822 <https://github.com/ioam/holoviews/pull/822>`_).
  * Added major layout fix for figures with non-square aspects, reducing
    the amount of unnecessary whitespace (PR `#826
    <https://github.com/ioam/holoviews/pull/826>`_). Disabled by default
    until 1.7 release but can be enabled with::
- Update to 1.6.1
  * Bug fix release following the 1.6 major release with major bug
    fixes for the grid data interfaces and improvements to the
    options system.
  * Ensured that style options incompatible with active backend are
    ignored (PR #802).
  * Added support for placing legends outside the plot area in
    bokeh (PR #801).
  * Fix to ensure bokeh backend does not depend on pandas
    (PR #792).
  * Fixed option system to ensure correct inheritance when
    redefining options (PR #796).
  * Major refactor and fixes for the grid based data backends
    (iris, xarray and arrays with coordinates) ensuring the data
    is oriented and transposed correctly (PR #794).
- update to version 1.6.0:
  * Made VectorFieldPlot more general with support for independent
    coloring and scaling (PR #701).
  * Iris interface now allows tuple and dict formats in the
    constructor (PR #709.
  * Added support for dynamic groupby on all data interfaces (PR
    [#711]).
  * Added an xarray data interface (PR #713).
  * Addded the redim method to all Dimensioned objects making it easy
    to quickly change dimension names and attributes on nested objects
    [#715]).
  * Added support for batching plots (PR #715).
  * Support for bokeh 0.12 release (PR #725).
  * Added support for logz option on bokeh Raster plots (PR #729).
  * Bokeh plots now support custom tick formatters specified via
    Dimension value_format (PR #728).
- Update to version 1.5.0
  + A major release with a large number of new features including
    new data interfaces for grid based data, major improvements for
    DynamicMaps and a large number of bug fixes.
  + Features and improvements:
  * Added a grid based data interface to explore n-dimensional gridded
    data easily.
  * Added data interface based on iris Cubes.
  * Added support for dynamic operations and overlaying of DynamicMaps.
  * Added support for applying groupby operations to DynamicMaps.
  * Added dimension value formatting in widgets.
  * Added support for indexing and slicing with a function.
  * Improved throttling behavior on widgets.
  * Major refactor of matplotlib plotting classes to simplify
    implementing new Element plots.
  * Added Renderer.last_plot attribute to allow easily debugging or
    modifying the last displayed plot.
  * Added bokeh QuadMeshPlot.
  + Bug fixes:
  * Fixed overlaying of 3D Element types.
  * Fix for bokeh hovertools with dimensions with special characters.
  * Fixed bugs in seaborn Distribution Element.
  * Fix for inverted Raster.reduce method.
  * Fixed Store.add_style_opts method.
  * Fixed bug preventing simultaneous logx and logy plot options.
  + Backwards compatibility:
  * Renamed ``Columns`` type to ``Dataset``.
- update to version 1.4.3:
  * Added a DynamicMap Tutorial to explain how to explore very large
    or continuous parameter spaces in HoloViews (PR #470).
  * Various fixes and improvements for DynamicMaps including slicing
    (PR #488) and validation (PR #483) and serialization (PR #483)
  * Widgets containing matplotlib plots now display the first frame
    from cache providing at least the initial frame when exporting
    DynamicMaps (PR #486)
  * Fixed plotting bokeh plots using widgets in live mode, after
    changes introduced in latest bokeh version (commit 1b87c91e9).
  * Fixed issue in coloring Point/Scatter objects by values (Issue
    [#467]).
  * The behavior of the scaling_factor on Point and Scatter plots has
    changed now simply multiplying area or width (as defined by the
    scaling_method). To disable scaling points by a dimension set
    size_index=None.
  * Removed hooks to display 3D Elements using the BokehMPLRawWrapper
    in bokeh (PR #477)
  * Renamed the DynamicMap mode closed to bounded (PR #477)
- update to version 1.4.2:
  * Over the past month since the 1.4.1 release, we have improved our
    infrastructure for building documentation, updated the main
    website and made several additional usability improvements.
  * Documentation changes:
    + Major overhaul of website and notebook building making it much
    easier to test user contributions (Issue #180, PR #429)
    + Major rewrite of the documentation (PR #401, PR #411)
    + Added Columnar Data Tutorial and removed most of Pandas
    Conversions as it is now supported by the core.
  * Fixes and improvements:
    + Major improvement for grid based layouts with varying aspects
    (PR #457)
    + Fix for interleaving %%matplotline inline and holoviews plots
    (Issue #179)
    + Matplotlib legend z-orders and updating fixed (Issue #304, Issue
    [#305])
    + color_index and size_index plot options support specifying
    dimension by name (Issue #391)
    + Added Area Element type for drawing area under or between
    Curves. (PR #427)
    + Fixed issues where slicing would remove styles applied to an
    Element. (Issue #423, PR #439)
    + Updated the title_format plot option to support a {dimensions}
    formatter (PR #436)
    + Improvements to Renderer API to allow JS and CSS requirements
    for exporting standalone widgets (PR #426)
    + Compatibility with the latest Bokeh 0.11 release (PR #393)
- update to version 1.4.1:
  * New features:
    + Improved help system. It is now possible to recursively list all
    the applicable documentation for a composite object. In addition,
    the documentation may now be filtered using a regular expression
    pattern. (PR #370)
    + HoloViews now supports multiple active display hooks making it
    easier to use nbconvert. For instance, PNG data will be embedded
    in the notebook if the argument display_formats=['html','png'] is
    supplied to the notebook_extension. (PR #355)
    + Improvements to the display of DynamicMaps as well as many new
    improvements to the Bokeh backend including better VLines/HLines
    and support for the Bars element. (PR #367 , PR #362, PR #339).
    + New Spikes and BoxWhisker elements suitable for representing
    distributions as a sequence of lines or as a box-and-whisker
    plot. (PR #346, PR #339)
    + Improvements to the notebook_extension. For instance, executing
    hv.notebook_extension('bokeh') will now load BokehJS and
    automatically activate the Bokeh backend (if available).
    + Significant performance improvements when using the groupby
    operation on HoloMaps and when working with highly nested
    datastructures. (PR #349, PR #359)
  * Notable bug fixes:
    + DynamicMaps are now properly integrated into the style system
    and can be customized in the same way as HoloMaps. (PR #368)
    + Widgets now work correctly when unicode is used in the dimension
    labels and values (PR #376).
- update to version 1.4.0:
  * Major new features:
    + Data API: The new data API brings an extensible system of to add
    new data interfaces to column based Element types. These
    interfaces allow applying powerful operations on the data
    independently of the data format. The currently supported
    datatypes include NumPy, pandas dataframes and a simple
    dictionary format. (PR #284)
    + Backend API: In this release we completely refactored the
    rendering, plotting and IPython display system to make it easy to
    add new plotting backends. Data may be styled and pickled for each
    backend independently and renderers now support exporting all
    plotting data including widgets as standalone HTML files or with
    separate JSON data.
    + Bokeh backend: The first new plotting backend added via the new
    backend API. Bokeh plots allow for much faster plotting and
    greater interactivity. Supports most Element types and layouts and
    provides facilities for sharing axes across plots and linked
    brushing across plots. (PR #250)
    + DynamicMap: The new DynamicMap class allows HoloMap data to be
    generated on-the-fly while running a Jupyter IPython notebook
    kernel. Allows visualization of unbounded data streams and smooth
    exploration of large continuous parameter spaces. (PR #278)
  * Other features:
    + Easy definition of custom aliases for group, label and Dimension
    names, allowing easier use of LaTeX.
    + New Trisurface and QuadMesh elements.
    + Widgets now allow expressing hierarchical relationships between
    dimensions.
    + Added GridMatrix container for heterogeneous Elements and
    gridmatrix operation to generate scatter matrix showing
    relationship between dimensions.
    + Filled contour regions can now be generated using the contours
    operation.
    + Consistent indexing semantics for all Elements and support for
    boolean indexing for Columns and NdMapping types.
    + New hv.notebook_extension function offers a more flexible
    alternative to %%load_ext, e.g. for loading other extensions
    hv.notebook_extension(bokeh=True).
  * Experimental features:
    + Bokeh callbacks allow adding interactivity by communicating
    between bokehJS tools and the IPython kernel, e.g. allowing
    downsampling based on the zoom level.
  * Notable bug fixes:
    + Major speedup rendering large HoloMaps (~ 2-3 times faster).
    + Colorbars now consistent for all plot configurations.
    + Style pickling now works correctly.
  * API Changes:
    + Dimension formatter parameter now deprecated in favor of
    value_format.
    + Types of Chart and Table Element data now dependent on selected
    interface.
    + DFrame conversion interface deprecated in favor of Columns
    pandas interface.
* Fri Jul 10 2015 toddrme2178@gmail.com
- Update to version 1.3.2
  + Minor bugfix release to address a small number of issues:
  + Features:
  * Added support for colorbars on Surface Element (1cd5281).
  * Added linewidth style option to SurfacePlot (9b6ccc5).
  + Bug fixes:
  * Fixed inversion inversion of y-range during sampling (6ff81bb).
  * Fixed overlaying of 3D elements (787d511).
  * Ensuring that underscore.js is loaded in widgets (f2f6378).
  * Fixed Python3 issue in Overlay.get (8ceabe3).
- Update to version 1.3.1
  + Minor bugfix release to address a number of issues that weren't caught
    in time for the 1.3.0 release with the addition of a small number of
    features
  + Features:
  * Introduced new ``Spread`` element to plot errors and confidence
    intervals (30d3184).
  * ``ErrorBars`` and ``Spread`` elements now allow most Chart
    constructor types (f013deb).
  + Bug fixes:
  * Fixed unicode handling for dimension labels (061e9af).
  * Handling of invalid dimension label characters in widgets (a101b9e).
  * Fixed setting of fps option for MPLRenderer video output (c61b9df).
  * Fix for multiple and animated colorbars (5e1e4b5).
  * Fix to Chart slices starting or ending at zero (edd0039).
- Update to version 1.3.0
  + Since the last release we closed over 34 issues and have made 380
    commits mostly focused on fixing bugs, cleaning up the API and
    working extensively on the plotting and rendering system to
    ensure HoloViews is fully backend independent.
  + Highlights/Features:
  * Allowed display of data structures which do not match the
    recommended nesting hierarchy (67b28f3, fbd89c3).
  * Dimensions now sanitized for ``.select``, ``.sample`` and
    ``.reduce`` calls (6685633, 00b5a66).
  * Added ``holoviews.ipython.display`` function to render (and display)
    any HoloViews object, useful for IPython interact widgets (0fa49cd).
  * Table column widths now adapt to cell contents (be90a54).
  * Defaulting to matplotlib ticking behavior (62e1e58).
  * Allowed specifying fixed figure sizes to matplotlib via
    ``fig_inches`` tuples using (width, None) and (None, height) formats
    (632facd).
  * Constructors of ``Chart``, ``Path`` and ``Histogram`` classes now support
    additional data formats (2297375).
  * ``ScrubberWidget`` now supports all figure formats (c317db4).
  * Allowed customizing legend positions on ``Bars`` Elements (5a12882).
  * Support for multiple colorbars on one axis (aac7b92).
  * ``.reindex`` on ``NdElement`` types now support converting between
    key and value dimensions allowing more powerful conversions. (03ac3ce)
  * Improved support for casting between ``Element`` types (cdaab4e, b2ad91b,
    ce7fe2d, 865b4d5).
  * The ``%%%%opts`` cell magic may now be used multiple times in the same
    cell (2a77fd0)
  * Matplotlib rcParams can now be set correctly per figure (751210f).
  * Improved ``OptionTree`` repr which now works with eval (2f824c1).
  * Refactor of rendering system and IPython extension to allow easy
    swapping of plotting backend (#141)
  * Large plotting optimization by computing tight ``bbox_inches`` once
    (e34e339).
  * Widgets now cache frames in the DOM, avoiding flickering in some
    browsers and make use of jinja2 template inheritance. (fc7dd2b)
  * Calling a HoloViews object without arguments now clears any
    associated custom styles. (9e8c343)
  + API Changes
  * Renamed key_dimensions and value_dimensions to kdims and vdims
    respectively, while providing backward compatibility for passing
    and accessing the long names (8feb7d2).
  * Combined x/y/zticker plot options into x/y/zticks parameters which
    now accept an explicit number of ticks, an explicit list of tick
    positions (and labels), and a matplotlib tick locator.
  * Changed backend options in %%output magic, ``nbagg`` and ``d3`` are
    now modes of the matplotlib backend and can be selected with
    ``backend='matplotlib:nbagg'`` and ``backend='matplotlib:mpld3'``
    respectively. The 'd3' and 'nbagg' options remain supported but will
    be deprecated in future.
  * Customizations should no longer be applied directly to ``Store.options``;
    the ``Store.options(backend='matplotlib')`` object should be
    customized instead.  There is no longer a need to call the
    deprecated ``Store.register_plots`` method.
- update to version 1.2.0:
  * Highlights/Features:
  - Added new ErrorBars Element (f2b276b)
  - Added Empty pseudo-Element to define empty placeholders in
    Layouts (35bac9f1d)
  - Added support for changing font sizes easily (0f54bea)
  - Support for holoviews.rc file (79076c8)
  - Many major speed optimizations for working with and plotting
    HoloViews data structures (fe87b4c, 7578c51, 5876fe6, 8863333)
  - Support for GridSpace with inner axes (93295c8)
  - New aspect_weight and tight Layout plot options for more
    customizability of Layout arrangements (4b1f03d, e6a76b7)
  - Added bgcolor plot option to easily set axis background color
    (92eb95c)
  - Improved widget layout (f51af02)
  - New OutputMagic css option to style html output (9d42dc2)
  - Experimental support for PDF output (1e8a59b)
  - Added support for 3D interactivity with nbagg (781bc25)
  - Added ability to support deprecated plot options in %%%%opts
    magic.
  - Added DrawPlot simplifying the implementation of custom plots
    (38e9d44)
  * API changes:
  - Path and Histogram support new constructors (7138ef4, 03b5d38)
  - New depth argument on the relabel method (f89b89f)
  - Interface to Pandas improved (1a7cd3d)
  - Removed xlim, ylim and zlim to eliminate redundancy.
  - Renaming of various plot and style options including:
    + figure_* to fig_*
    + vertical_spacing and horizontal_spacing to vspace and hspace
    respectively
    + Deprecation of confusing origin style option on RasterPlot
  - Overlay.__getitem__ no longer supports integer indexing (use get
    method instead)
  * Important bug fixes:
  - Important fixes to inheritance in the options system (d34a931,
    71c1f3a7)
  - Fixes to the select method (df839bea5)
  - Fixes to normalization system (c3ef40b)
  - Fixes to Raster and Image extents, __getitem__ and sampling.
  - Fixed bug with disappearing adjoined plots (2360972)
  - Fixed plot ordering of overlaid elements across a HoloMap
    (c4f1685)
- update to version 1.1.0:
  * Highlights:
    + Support for nbagg as a backend (09eab4f1)
    + New .hvz file format for saving HoloViews objects (bfd5f7af)
    + New Polygon element type (d1ec8ec8)
    + Greatly improved Unicode support throughout, including support
    for unicode characters in Python 3 attribute names (609a8454)
    + Regular SelectionWidget now supports live rendering (eb5bf8b6)
    + Supports a list of objects in Layout and Overlay constructors
    (5ba1866e)
    + Polar projections now supported (3801b76e)
  * API changes (not backward compatible):
    + xlim, ylim, zlim, xlabel, ylabel and zlabel have been deprecated
    (081d4123)
    + Plotting options show_xaxis and show_yaxis renamed to xaxis and
    yaxis, respectively (13393f2a).
    + Deprecated IPySelectionWidget (f59c34c0)
  * In addition to the above improvements, many miscellaneous bug fixes were made.
* Thu Apr  9 2015 toddrme2178@gmail.com
- Initial version
